@@ -8,7 +8,6 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 require Exporter;
 require DynaLoader;
 require AutoLoader;
-require Digest::MD5;
 
 @ISA = qw(Exporter DynaLoader);
 # Items to export into callers namespace by default. Note: do not export
@@ -20,7 +19,7 @@ require Digest::MD5;
    NameSpace_URL
    NameSpace_X500
 );
-$VERSION = '1.200_02';
+$VERSION = '1.148';
 
 # Preloaded methods go here.
 
